<?php
// Copyright 1999-2017. Plesk International GmbH. All rights reserved.

namespace Atf\ComposerAtfVersions;

use Composer\Factory;
use Composer\Installer;
use Composer\IO\IOInterface;

/**
 * Run composer in (sub-)directories.
 */
class SubComposer
{
    /**
     * @var string[]
     */
    private $directories;

    /**
     * SubComposer constructor.
     * @param string[] $directories
     */
    public function __construct(array $directories)
    {
        $this->directories = $directories;
    }

    /**
     * @param IOInterface $io
     * @param bool $isUpdate
     */
    public function run(IOInterface $io, $isUpdate = false)
    {
        $io->write('Process composer.json in plesk-versions');

        $factory = new Factory();
        $oldWorkDir = getcwd();
        $env = new EnvHolderSet();
        try {
            $env->without('COMPOSER_VENDOR_DIR')
                ->without('COMPOSER_BIN_DIR');
            foreach ($this->directories as $wd) {
                $io->write('----------------------------------------------------------------');
                $io->write('Work dir: ' . $wd);

                self::touchTestsDir($wd);
                chdir($wd);
                $composer = $factory->createComposer($io, "{$wd}/composer.json", false, $wd);
                $installer = Installer::create($io, $composer);
                //:INFO: Workaround for install on old php version
                $installer->setIgnorePlatformRequirements(true);
                $installer->setDevMode(true);
                $installer->setUpdate($isUpdate);
                $installer->run();
            }
        } finally {
            $env->rollback();
            if ($oldWorkDir !== false) {
                chdir($oldWorkDir);
            }
        }

        $io->write('End of ' . __METHOD__);
    }

    /**
     * Need for autodetect ATF-projects application directory
     *
     * @todo remove after complete task https://jira.plesk.ru/browse/ATF-86
     * @param $wd
     */
    protected static function touchTestsDir($wd)
    {
        is_file($wd . '/composer.json') || mkdir($wd . '/tests', 0777, true);
    }
}
