#  Copyright 1999-2021. Plesk International GmbH. All rights reserved.

package Cpanel::API::WpToolkitCli;

use strict;

our $VERSION = '1.0';

use Cpanel::AdminBin::Call;
use Try::Tiny;
use JSON::XS;

sub execute_command {
    my ($args, $result) = @_;
    my $isSuccess = 0;
    try {
        if (!main::hasfeature('wp-toolkit')) {
            die "Access denied! You don't have permission \"wp-toolkit\".";
        }

        my $command = $args->get_required('command');
        my @params = $args->get_multiple('command-param');
        my @commandArgs = ($command, @params);

        my ($stdout, $stderr, $exitCode) = Cpanel::AdminBin::Call::call(
            "Cpanel",
            "WpToolkitCli",
            "execute_command",
            @commandArgs
        );

        if ($exitCode == 0) {
            # Success
            # decode_json throw error if $stdout cannot be parsed as JSON
            $result->data(decode_json($stdout));
            $isSuccess = 1;

        } elsif ($exitCode == 256) {
            # Has returned result of --help command
            $result->error('Command does not exist.');

        } else {
            # Message will be in $stdout or $stderr
            $result->error($stdout . $stderr);
        }
    }
    catch {
        my $e = $_;
        if ($e->can("to_string")) {
            $result->error($e->to_string());
        } else {
            $result->error($e);
        }
    };
    return $isSuccess
}

1;
